@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2008-2009 Mike Massonnet <mmassonnet@xfce.org>
+ *  Copyright (c) 2008-2011 Mike Massonnet <mmassonnet@xfce.org>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
@@ -22,7 +22,6 @@
 
 #include <gtk/gtk.h>
 #include <libxfce4util/libxfce4util.h>
-#include <xfconf/xfconf.h>
 
 #include "common.h"
 #include "actions.h"
@@ -60,8 +59,6 @@ enum
   INHIBIT,
 };
 
-static void             clipman_collector_class_init        (ClipmanCollectorClass *klass);
-static void             clipman_collector_init              (ClipmanCollector *collector);
 static void             clipman_collector_constructed       (GObject *object);
 static void             clipman_collector_finalize          (GObject *object);
 static void             clipman_collector_set_property      (GObject *object,
@@ -95,15 +92,14 @@ cb_clipboard_owner_change (ClipmanCollector *collector,
   gboolean has_image;
   gchar *text;
   GdkPixbuf *image;
-  GdkAtom text_plain, text_html;
 
-  /* Skip if the collector is inhibit */
-  if (collector->priv->inhibit == TRUE)
-    return;
+  g_return_if_fail (GTK_IS_CLIPBOARD (collector->priv->default_clipboard) && GTK_IS_CLIPBOARD (collector->priv->primary_clipboard));
 
-  /* Take only care of new clipboard content */
-  if (event->reason != GDK_OWNER_CHANGE_NEW_OWNER)
-    return;
+  /* Jump over if collector is inhibited */
+  if (collector->priv->inhibit)
+    {
+      return;
+    }
 
   /* Jump over if the content is set from within clipman */
   if (collector->priv->internal_change)
@@ -117,39 +113,20 @@ cb_clipboard_owner_change (ClipmanCollector *collector,
     {
       has_text = gtk_clipboard_wait_is_text_available (collector->priv->default_clipboard);
       has_image = gtk_clipboard_wait_is_image_available (collector->priv->default_clipboard);
-
       if (has_text)
         {
           text = gtk_clipboard_wait_for_text (collector->priv->default_clipboard);
           if (text != NULL && text[0] != '\0')
-            {
-              /* Make Clipman the owner only if it has the target text/plain or text/html */
-              text_plain = gdk_atom_intern_static_string ("text/plain");
-              text_html = gdk_atom_intern_static_string ("text/html");
-              if (gtk_clipboard_wait_is_target_available (collector->priv->default_clipboard, text_plain)
-                  || gtk_clipboard_wait_is_target_available (collector->priv->default_clipboard, text_html))
-                {
-                  collector->priv->internal_change = TRUE;
-                  gtk_clipboard_set_text (collector->priv->default_clipboard, text, -1);
-                }
-
-              /* Add to history */
-              clipman_history_add_text (collector->priv->history, text);
-            }
+            clipman_history_add_text (collector->priv->history, text);
+          if (collector->priv->enable_actions)
+            clipman_actions_match_with_menu (collector->priv->actions, ACTION_GROUP_MANUAL, text);
           g_free (text);
         }
       else if (has_image)
         {
           image = gtk_clipboard_wait_for_image (collector->priv->default_clipboard);
           if (image != NULL)
-            {
-              /* Make Clipman the owner */
-              collector->priv->internal_change = TRUE;
-              gtk_clipboard_set_image (collector->priv->default_clipboard, image);
-
-              /* Add to history */
-              clipman_history_add_image (collector->priv->history, image);
-            }
+            clipman_history_add_image (collector->priv->history, image);
           g_object_unref (image);
         }
     }
@@ -159,7 +136,9 @@ cb_clipboard_owner_change (ClipmanCollector *collector,
        * actually check inside a delayed timeout if the mouse is still pressed
        * or if the shift key is hold down, and once both are released the
        * content will go to the history. */
-      if (collector->priv->add_primary_clipboard || collector->priv->enable_actions)
+      if (collector->priv->add_primary_clipboard
+          || !collector->priv->history_ignore_primary_clipboard
+          || collector->priv->enable_actions)
         {
           if (collector->priv->primary_clipboard_timeout == 0)
             collector->priv->primary_clipboard_timeout =
@@ -173,13 +152,15 @@ cb_check_primary_clipboard (ClipmanCollector *collector)
 {
   GdkModifierType state;
   gchar *text;
+  static gchar *prev_text = NULL;
+
+  g_return_if_fail (GTK_IS_CLIPBOARD (collector->priv->default_clipboard) && GTK_IS_CLIPBOARD (collector->priv->primary_clipboard));
 
   /* Postpone until the selection is done */
   gdk_window_get_pointer (NULL, NULL, NULL, &state);
   if (state & (GDK_BUTTON1_MASK|GDK_SHIFT_MASK))
     return TRUE;
 
-  /* Copy the text to the history */
   if (gtk_clipboard_wait_is_text_available (collector->priv->primary_clipboard))
     {
       text = gtk_clipboard_wait_for_text (collector->priv->primary_clipboard);
@@ -189,14 +170,20 @@ cb_check_primary_clipboard (ClipmanCollector *collector)
           if (collector->priv->add_primary_clipboard
               && collector->priv->history_ignore_primary_clipboard)
             collector->priv->internal_change = TRUE;
+          else if (!collector->priv->history_ignore_primary_clipboard)
+            clipman_history_add_text (collector->priv->history, text);
 
           /* Make a copy inside the default clipboard */
           if (collector->priv->add_primary_clipboard)
             gtk_clipboard_set_text (collector->priv->default_clipboard, text, -1);
 
           /* Match for actions */
-          if (collector->priv->enable_actions)
-            clipman_actions_match_with_menu (collector->priv->actions, text);
+          if (collector->priv->enable_actions && g_strcmp0 (text, prev_text))
+            {
+              clipman_actions_match_with_menu (collector->priv->actions, ACTION_GROUP_SELECTION, text);
+              g_free (prev_text);
+              prev_text = g_strdup (text);
+            }
         }
       g_free (text);
     }
@@ -226,23 +213,8 @@ clipman_collector_set_is_restoring (ClipmanCollector *collector)
   collector->priv->internal_change = TRUE;
 }
 
-/**
- * clipman_collector_inhibit:
- * @collector: a #ClipmanCollector
- * @inhibit: TRUE if the collector should be deactivated
- *
- * Set to TRUE to disable the collector, FALSE to let it read the clipboard
- * contents.
- */
-void
-clipman_collector_inhibit (ClipmanCollector *collector,
-                           gboolean inhibit)
-{
-  g_object_set (collector, "inhibit", inhibit, NULL);
-}
-
 ClipmanCollector *
-clipman_collector_get ()
+clipman_collector_get (void)
 {
   static ClipmanCollector *singleton = NULL;
 
