@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2008-2009 Mike Massonnet <mmassonnet@xfce.org>
+ *  Copyright (c) 2008-2011 Mike Massonnet <mmassonnet@xfce.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 
 #include <glib/gstdio.h>
 #include <gtk/gtk.h>
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include "common.h"
 #include "plugin.h"
@@ -42,8 +42,6 @@ static void             cb_status_icon_popup_menu       (MyPlugin *plugin,
                                                          guint button,
                                                          guint activate_time);
 static void             cb_status_icon_quit             (MyPlugin *plugin);
-static gboolean         cb_status_icon_set_size         (MyPlugin *plugin,
-                                                         gint size);
 static void             cb_status_icon_finalize         (MyPlugin *plugin);
 static void             install_autostart_file          ();
 static void             update_autostart_file           ();
@@ -76,12 +74,23 @@ main (gint argc,
  */
 
 static MyPlugin *
-status_icon_register ()
+status_icon_register (void)
 {
   MyPlugin *plugin = plugin_register ();
+  GtkIconTheme *icon_theme = gtk_icon_theme_get_default ();
+
+  /* Menu Position Func */
+  plugin->menu_position_func = (GtkMenuPositionFunc)gtk_status_icon_position_menu;
 
   /* Status Icon */
-  plugin->status_icon = gtk_status_icon_new_from_stock (GTK_STOCK_PASTE);
+  if (gtk_icon_theme_has_icon (icon_theme, "clipman"))
+    {
+      plugin->status_icon = gtk_status_icon_new_from_icon_name ("clipman");
+    }
+  else
+    {
+      plugin->status_icon = gtk_status_icon_new_from_stock (GTK_STOCK_PASTE);
+    }
   gtk_status_icon_set_tooltip (plugin->status_icon, _("Clipman"));
   g_timeout_add_seconds (60, (GSourceFunc)cb_status_icon_is_embedded, plugin->status_icon);
 
@@ -110,10 +119,7 @@ cb_status_icon_is_embedded (GtkStatusIcon *status_icon)
 static void
 cb_status_icon_activate (MyPlugin *plugin)
 {
-  gtk_menu_set_screen (GTK_MENU (plugin->menu), gtk_status_icon_get_screen (plugin->status_icon));
-  gtk_menu_popup (GTK_MENU (plugin->menu), NULL, NULL,
-                  (GtkMenuPositionFunc)gtk_status_icon_position_menu, plugin->status_icon,
-                  0, gtk_get_current_event_time ());
+  plugin_popup_menu (plugin);
 }
 
 static void
@@ -124,11 +130,6 @@ cb_status_icon_popup_menu (MyPlugin *plugin, guint button, guint activate_time)
   if (G_UNLIKELY (plugin->popup_menu == NULL))
     {
       plugin->popup_menu = gtk_menu_new ();
-      mi = gtk_menu_item_new_with_label (_("Clipman"));
-      gtk_widget_set_sensitive (mi, FALSE);
-      gtk_menu_shell_append (GTK_MENU_SHELL (plugin->popup_menu), mi);
-      mi = gtk_separator_menu_item_new ();
-      gtk_menu_shell_append (GTK_MENU_SHELL (plugin->popup_menu), mi);
       mi = gtk_image_menu_item_new_from_stock (GTK_STOCK_PROPERTIES, NULL);
       gtk_menu_shell_append (GTK_MENU_SHELL (plugin->popup_menu), mi);
       g_signal_connect_swapped (mi, "activate", G_CALLBACK (plugin_configure), plugin);
@@ -137,7 +138,7 @@ cb_status_icon_popup_menu (MyPlugin *plugin, guint button, guint activate_time)
       g_signal_connect_swapped (mi, "activate", G_CALLBACK (plugin_about), plugin);
       mi = gtk_separator_menu_item_new ();
       gtk_menu_shell_append (GTK_MENU_SHELL (plugin->popup_menu), mi);
-      mi = gtk_image_menu_item_new_from_stock (GTK_STOCK_REMOVE, NULL);
+      mi = gtk_image_menu_item_new_from_stock (GTK_STOCK_QUIT, NULL);
       g_signal_connect_swapped (mi, "activate", G_CALLBACK (cb_status_icon_quit), plugin);
       gtk_menu_shell_append (GTK_MENU_SHELL (plugin->popup_menu), mi);
       gtk_widget_show_all (plugin->popup_menu);
@@ -145,7 +146,7 @@ cb_status_icon_popup_menu (MyPlugin *plugin, guint button, guint activate_time)
 
   gtk_menu_set_screen (GTK_MENU (plugin->popup_menu), gtk_status_icon_get_screen (plugin->status_icon));
   gtk_menu_popup (GTK_MENU (plugin->popup_menu), NULL, NULL,
-                  (GtkMenuPositionFunc)NULL, NULL,
+                  (GtkMenuPositionFunc)gtk_status_icon_position_menu, plugin->status_icon,
                   0, gtk_get_current_event_time ());
 }
 
@@ -165,11 +166,10 @@ cb_status_icon_finalize (MyPlugin *plugin)
 }
 
 static void
-install_autostart_file ()
+install_autostart_file (void)
 {
   gchar *sysfile;
   gchar *userfile;
-  gint res;
   GKeyFile *keyfile;
   gchar *data;
 
@@ -207,7 +207,6 @@ static void
 update_autostart_file (gboolean autostart)
 {
   gchar *userfile;
-  gint res;
   GKeyFile *keyfile;
   gchar *data;
 
@@ -225,6 +224,8 @@ update_autostart_file (gboolean autostart)
   keyfile = g_key_file_new ();
   g_key_file_load_from_file (keyfile, userfile, G_KEY_FILE_KEEP_TRANSLATIONS, NULL);
   g_key_file_set_boolean (keyfile, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_HIDDEN, !autostart);
+  g_key_file_set_string (keyfile, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_TRY_EXEC, "xfce4-clipman");
+  g_key_file_set_string (keyfile, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_EXEC, "xfce4-clipman");
   data = g_key_file_to_data (keyfile, NULL, NULL);
   g_file_set_contents (userfile, data, -1, NULL);
   g_free (data);
