@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2009 Mike Massonnet <mmassonnet@xfce.org>
+ *  Copyright (c) 2009-2011 Mike Massonnet <mmassonnet@xfce.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -46,7 +46,7 @@ struct _MyPlugin
   XfcePanelPlugin      *panel_plugin;
   GtkWidget            *button;
   GtkWidget            *image;
-#elif STATUS_ICON
+#elif defined (STATUS_ICON)
   GtkStatusIcon        *status_icon;
 #endif
   GsdClipboardManager  *daemon;
@@ -70,7 +70,7 @@ void                    plugin_save                     (MyPlugin *plugin);
 void                    plugin_free                     (MyPlugin *plugin);
 void                    plugin_about                    (MyPlugin *plugin);
 void                    plugin_configure                (MyPlugin *plugin);
-void                    plugin_menu_popup               (MyPlugin *plugin);
+void                    plugin_popup_menu               (MyPlugin *plugin);
 
 #endif /* !__CLIPMAN_PLUGIN_H__ */
 
