@@ -75,6 +75,7 @@ static void
 prop_dialog_run (void)
 {
   GtkWidget *action_dialog;
+  GtkWidget *combobox;
 
   builder = gtk_builder_new ();
   gtk_builder_add_from_string (builder, settings_dialog_ui, settings_dialog_ui_length, NULL);
@@ -90,8 +91,6 @@ prop_dialog_run (void)
                                 DEFAULT_HISTORY_IGNORE_PRIMARY_CLIPBOARD);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "save-on-quit")),
                                 DEFAULT_SAVE_ON_QUIT);
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "reverse-order")),
-                                DEFAULT_REVERSE_ORDER);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "store-an-image")),
                                 (gboolean)DEFAULT_MAX_IMAGES_IN_HISTORY);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (gtk_builder_get_object (builder, "max-texts-in-history")),
@@ -103,8 +102,6 @@ prop_dialog_run (void)
                           gtk_builder_get_object (builder, "history-ignore-selections"), "active");
   xfconf_g_property_bind (xfconf_channel, "/settings/save-on-quit", G_TYPE_BOOLEAN,
                           gtk_builder_get_object (builder, "save-on-quit"), "active");
-  xfconf_g_property_bind (xfconf_channel, "/tweaks/reverse-menu-order", G_TYPE_BOOLEAN,
-                          gtk_builder_get_object (builder, "reverse-order"), "active");
   xfconf_g_property_bind (xfconf_channel, "/settings/max-images-in-history", G_TYPE_UINT,
                           gtk_builder_get_object (builder, "store-an-image"), "active");
   xfconf_g_property_bind (xfconf_channel, "/settings/max-texts-in-history", G_TYPE_UINT,
@@ -151,6 +148,55 @@ prop_dialog_run (void)
   g_signal_connect_swapped (gtk_builder_get_object (builder, "action-dialog-button-cancel"), "clicked",
                              G_CALLBACK (gtk_dialog_response), action_dialog);
 
+  /* Tweaks tab */
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "popup-at-pointer")),
+                                DEFAULT_POPUP_AT_POINTER);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "reorder-items")),
+                                DEFAULT_REORDER_ITEMS);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "reverse-order")),
+                                DEFAULT_REVERSE_ORDER);
+  gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (builder, "skip-action")),
+                            DEFAULT_ENABLE_ACTIONS);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, "skip-action")),
+                                DEFAULT_SKIP_ACTION_ON_KEY_DOWN);
+
+  xfconf_g_property_bind (xfconf_channel, "/tweaks/popup-at-pointer", G_TYPE_BOOLEAN,
+                          gtk_builder_get_object (builder, "popup-at-pointer"), "active");
+  xfconf_g_property_bind (xfconf_channel, "/tweaks/reorder-items", G_TYPE_BOOLEAN,
+                          gtk_builder_get_object (builder, "reorder-items"), "active");
+  xfconf_g_property_bind (xfconf_channel, "/tweaks/reverse-menu-order", G_TYPE_BOOLEAN,
+                          gtk_builder_get_object (builder, "reverse-order"), "active");
+  xfconf_g_property_bind (xfconf_channel, "/settings/enable-actions", G_TYPE_BOOLEAN,
+                          gtk_builder_get_object (builder, "skip-action"), "sensitive");
+  xfconf_g_property_bind (xfconf_channel, "/tweaks/skip-action-on-key-down", G_TYPE_BOOLEAN,
+                          gtk_builder_get_object (builder, "skip-action"), "active");
+
+  /* Tweaks tab: paste-on-activate combobox */
+  combobox = GTK_WIDGET (gtk_builder_get_object (builder, "combobox-paste-on-activate"));
+
+  {
+    GtkListStore *store;
+    GtkCellRenderer *cell;
+
+    store = gtk_list_store_new (1, G_TYPE_STRING);
+    gtk_combo_box_set_model (GTK_COMBO_BOX (combobox), GTK_TREE_MODEL (store));
+    g_object_unref (store);
+
+    cell = gtk_cell_renderer_text_new ();
+    gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combobox), cell, TRUE);
+    gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combobox), cell, "text", 0, NULL);
+  }
+
+  gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("None"));
+  /* TRANSLATORS: Keyboard shortcut */
+  gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("Ctrl+V"));
+  /* TRANSLATORS: Keyboard shortcut */
+  gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("Shift+Insert"));
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), 0);
+
+  xfconf_g_property_bind (xfconf_channel, "/tweaks/paste-on-activate",
+                          G_TYPE_UINT, G_OBJECT (combobox), "active");
+
   /* Run the dialog */
   while ((gtk_dialog_run (GTK_DIALOG (settings_dialog))) == 2);
 
